@@ -1,7 +1,7 @@
 import securepy.config.config as _conf
 from securepy.restrictor import Restrictor  # noqa
 from securepy.security import RESTRICTED_GLOBALS, SAFE_GLOBALS, UNRESTRICTED_GLOBALS  # noqa
-from securepy.stdcapture import StdCapture  # noqa
+from securepy.stdcapture import StdCapture, MemoryOverflow  # noqa
 from securepy.timing import CapturingTimedFunction, TimedFunction, TimedFunctionError  # noqa
 
 __title__ = _conf.NAME
